spacepy.radbelt.get_modelop_L — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- radbelt - Functions supporting radiation belt diffusion codes »

# spacepy.radbelt.get_modelop_L

`spacepy.radbelt.` `get_modelop_L`(f, L, Dm_old, Dm_new, Dp_old, Dp_new, Tdelta, NL)

  Advance the distribution function, f, discretized into the Lgrid, L, forward in time by a timestep, Tdelta. The off-grid current and next diffusion coefficients, D[m,p]_[old,new] will be used. The number of grid points is set by NL.

  This function performs the same calculation as the C-based code, spacepy.lib.solve_cnp. This code is very slow and should only be used when the C code fails to compile.

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- radbelt - Functions supporting radiation belt diffusion codes »